OC.L10N.register(
    "lib",
    {
    "Username" : "Nama pengguna",
    "Password" : "Kata laluan",
    "Apps" : "Aplikasi",
    "General" : "Umum",
    "Search" : "Cari",
    "Help" : "Bantuan",
    "Settings" : "Tetapan",
    "Users" : "Pengguna",
    "web services under your control" : "Perkhidmatan web di bawah kawalan anda",
    "Authentication error" : "Ralat pengesahan"
},
"nplurals=1; plural=0;");
